==> haskell-monad-logger-0.3.42-103.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-4mR0wENhtiT2BdGv1Hn8yK
key:                  monad-logger-0.3.42-4mR0wENhtiT2BdGv1Hn8yK
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  15177b8548983d1bfa0ae1bf99960d97
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-4mR0wENhtiT2BdGv1Hn8yK
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    conduit-extra-1.3.8-2AxhzRoObWI6EssRdl8CoW exceptions-0.10.7
    fast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx stm-2.5.1.0
    stm-chans-3.0.0.9-FlU5K8NwXr3CuyuM0prvJs template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.42-104-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-8CskNFmll7427ag5mqbmhY
key:                  monad-logger-0.3.42-8CskNFmll7427ag5mqbmhY
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  dbb8287ff32a061640f0a1df46f458e0
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-8CskNFmll7427ag5mqbmhY
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    conduit-extra-1.3.8-E4AHXAfmerjKj7JfHrF3lm exceptions-0.10.7
    fast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx stm-2.5.1.0
    stm-chans-3.0.0.9-FlU5K8NwXr3CuyuM0prvJs template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
